
# Slot: edges_number


The expected number of edges. Note that this must be the EXACT number of edges in the graph.

URI: [https://w3id.org/neat/ensmallenRunConfig__edges_number](https://w3id.org/neat/ensmallenRunConfig__edges_number)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
